@@ -7,7 +7,8 @@
 #include "dummypowernotifier.h"
 
 using namespace Solid;
-DummyPowerNotifier::DummyPowerNotifier(QObject* parent) : PowerNotifier(parent)
+DummyPowerNotifier::DummyPowerNotifier(QObject *parent)
+    : PowerNotifier(parent)
 {
     QMetaObject::invokeMethod(this, "emitEverythingChanged", Qt::QueuedConnection);
 }
@@ -16,3 +17,5 @@ void DummyPowerNotifier::emitEverythingChanged()
 {
     Q_EMIT acPluggedChanged(true);
 }
+
+#include "moc_dummypowernotifier.cpp"
